@@ -1,6 +1,5 @@
 import asyncio
 import importlib
-import inspect
 import json
 import logging
 import os
@@ -8,7 +7,7 @@ import warnings
 from contextvars import ContextVar
 from copy import deepcopy
 from inspect import isclass
-from typing import Any, Coroutine, Dict, List, Optional, Tuple, Type, Union, cast
+from typing import Coroutine, Dict, List, Optional, Tuple, Type, cast
 
 from pypika import Table
 
@@ -338,7 +337,7 @@ class Tortoise:
                     related_model._meta.add_field(backward_relation_name, m2m_relation)
 
     @classmethod
-    def _discover_client_class(cls, engine: str) -> BaseDBAsyncClient:
+    def _discover_client_class(cls, engine: str) -> Type[BaseDBAsyncClient]:
         # Let exception bubble up for transparency
         engine_module = importlib.import_module(engine)
 
@@ -380,7 +379,7 @@ class Tortoise:
             client_class = cls._discover_client_class(info.get("engine"))
             db_params = info["credentials"].copy()
             db_params.update({"connection_name": name})
-            connection = client_class(**db_params)  # type: ignore
+            connection = client_class(**db_params)
             if create_db:
                 await connection.db_create()
             await connection.create_connection(with_db=True)
@@ -639,4 +638,4 @@ def run_async(coro: Coroutine) -> None:
         loop.run_until_complete(Tortoise.close_connections())
 
 
-__version__ = "0.16.9"
+__version__ = "0.16.10"
